==> haskell-email-validate-2.3.2.21-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 email-validate
version:              2.3.2.21
visibility:           public
id:                   email-validate-2.3.2.21-CB1TOu82V447O7uAARCC5Z
key:                  email-validate-2.3.2.21-CB1TOu82V447O7uAARCC5Z
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  978ac5ed3f069812673c4d5fcb174dc2
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/email-validate-2.3.2.21
library-dirs:         /usr/lib/ghc-9.4.8/site-local/email-validate-2.3.2.21
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/email-validate-2.3.2.21
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/email-validate-2.3.2.21
hs-libraries:         HSemail-validate-2.3.2.21-CB1TOu82V447O7uAARCC5Z
depends:
    attoparsec-0.14.4-8oph4y3j0I1GXQUqU3wi8s base-4.17.2.1
    bytestring-0.11.5.3 template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.21-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 email-validate
version:              2.3.2.21
visibility:           public
id:                   email-validate-2.3.2.21-GKRCWJxjm0yElBn9GPstDf
key:                  email-validate-2.3.2.21-GKRCWJxjm0yElBn9GPstDf
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  6c0cc86864dccdeb4635df6fc640ff82
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/email-validate-2.3.2.21
library-dirs:         /usr/lib/ghc-9.4.8/site-local/email-validate-2.3.2.21
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/email-validate-2.3.2.21
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/email-validate-2.3.2.21
hs-libraries:         HSemail-validate-2.3.2.21-GKRCWJxjm0yElBn9GPstDf
depends:
    attoparsec-0.14.4-4euoXrooDbuLZe6Xn3rp2d base-4.17.2.1
    bytestring-0.11.5.3 template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
